==> spip_4.1.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Important group:</b> it is strongly advised to select a keyword in this group.',
	'avis_doublon_mot_cle' => 'A keyword with this title already exists. Are you sure you want to create the same again?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'site administrators',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'editors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitors of the public site when they post a message in a forum.',

	// C
	'creer_et_associer_un_mot' => 'Create and assign a keyword',

	// I
	'icone_creation_groupe_mots' => 'Create a new keyword group',
	'icone_creation_mots_cles' => 'Create a new keyword',
	'icone_modif_groupe_mots' => 'Edit this keyword group',
	'icone_modifier_mot' => 'Edit this keyword',
	'icone_mots_cles' => 'Keywords',
	'icone_supprimer_groupe_mots' => 'Delete this group',
	'icone_voir_groupe_mots' => 'Show this keyword group',
	'icone_voir_tous_mots_cles' => 'Show all keywords',
	'info_1_groupe_mots' => '1 keyword group',
	'info_articles_lies_mot' => 'Articles with this keyword',
	'info_aucun_groupe_mots' => 'No keyword group',
	'info_aucun_mot_cle' => 'No keywords',
	'info_changer_nom_groupe' => 'Change the name of this group:',
	'info_creation_mots_cles' => 'Create and configure site keywords here',
	'info_dans_groupe' => 'In group:',
	'info_delet_mots_cles' => 'You requested the deletion of keyword
<b>@titre_mot@</b> (@type_mot@). As this keyword is linked to
<b>@texte_lie@</b>you must confirm this decision:',
	'info_groupe_important' => 'Important group',
	'info_modifier_mot' => 'Edit the keyword:',
	'info_mots_cles' => 'Keywords',
	'info_mots_cles_association' => 'Keywords in this group can be associated with:',
	'info_nb_groupe_mots' => '@nb@ keyword groups',
	'info_oui_suppression_mot_cle' => 'I want to delete this keyword permanently.',
	'info_question_mots_cles' => 'Do you wish to use keywords on your site?',
	'info_qui_attribue_mot_cle' => 'Keywords in this group can be assigned by:',
	'info_remplacer_mot' => 'Replace "@titre@"',
	'info_retirer_mot' => 'Remove this keyword',
	'info_retirer_mots' => 'Remove all keywords',
	'info_rubriques_liees_mot' => 'Sections with this keyword',
	'info_selection_un_seul_mot_cle' => 'You can select only <b>one keyword</b> at a time in this group.',
	'info_supprimer_mot' => 'delete this keyword',
	'info_titre_mot_cle' => 'Keyword name or title',
	'info_un_mot' => 'One keyword at a time',
	'item_ajout_mots_cles' => 'Allow the use of keywords in forums',
	'item_non_ajout_mots_cles' => 'Do not allow use of keywords in forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Do not use the advanced keyword group configuration',
	'item_non_utiliser_mots_cles' => 'Do not use keywords',
	'item_utiliser_config_groupe_mots_cles' => 'Use advanced configuration for keyword groups',
	'item_utiliser_mots_cles' => 'Use keywords',

	// L
	'lien_ajouter_mot' => 'Add this keyword',
	'logo_groupe' => 'LOGO FOR THIS GROUP',
	'logo_mot_cle' => 'KEYWORD LOGO',

	// T
	'texte_config_groupe_mots_cles' => 'Do you want to activate advanced keyword configuration, e.g. to indicate that one unique word from the group may be used, that a group is important etc.?',
	'texte_mots_cles' => 'Keywords allow you to create topical links between your articles
  irrespective of their section. This can be used to
  improve site navigability, or even as a tool
  for customising site appearance in a template.',
	'texte_mots_cles_dans_forum' => 'Do you want to let visitors select keywords in the public forums? (Warning: this option is rather difficult to use properly)',
	'texte_nouveau_mot' => 'New keyword',
	'titre_config_groupe_mots_cles' => 'Configuration of the keyword groups',
	'titre_gauche_mots_edit' => 'KEYWORD NUMBER:',
	'titre_groupe_mots' => 'Keyword group',
	'titre_groupe_mots_numero' => 'KEYWORD GROUP NUMBER:',
	'titre_groupes_mots' => 'Keyword groups',
	'titre_mots_cles_dans_forum' => 'Keywords in the public site forums',
	'titre_mots_tous' => 'Keywords',
	'titre_nouveau_groupe' => 'New group',
	'titre_objets_lies_mot' => 'Linked to that keyword:',
	'titre_page_mots_tous' => 'Keywords'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_en.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Important group:</b> it is strongly advised to select a keyword in this group.',
	'avis_doublon_mot_cle' => 'A keyword with this title already exists. Are you sure you want to create the same again?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'site administrators',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'editors',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitors of the public site when they post a message in a forum.',

	// C
	'creer_et_associer_un_mot' => 'Create and assign a keyword',

	// I
	'icone_creation_groupe_mots' => 'Create a new keyword group',
	'icone_creation_mots_cles' => 'Create a new keyword',
	'icone_modif_groupe_mots' => 'Edit this keyword group',
	'icone_modifier_mot' => 'Edit this keyword',
	'icone_mots_cles' => 'Keywords',
	'icone_supprimer_groupe_mots' => 'Delete this group',
	'icone_voir_groupe_mots' => 'Show this keyword group',
	'icone_voir_tous_mots_cles' => 'Show all keywords',
	'info_1_groupe_mots' => '1 keyword group',
	'info_articles_lies_mot' => 'Articles with this keyword',
	'info_aucun_groupe_mots' => 'No keyword group',
	'info_aucun_mot_cle' => 'No keywords',
	'info_changer_nom_groupe' => 'Change the name of this group:',
	'info_creation_mots_cles' => 'Create and configure site keywords here',
	'info_dans_groupe' => 'In group:',
	'info_delet_mots_cles' => 'You requested the deletion of keyword
<b>@titre_mot@</b> (@type_mot@). As this keyword is linked to
<b>@texte_lie@</b>you must confirm this decision:',
	'info_groupe_important' => 'Important group',
	'info_modifier_mot' => 'Edit the keyword:',
	'info_mots_cles' => 'Keywords',
	'info_mots_cles_association' => 'Keywords in this group can be associated with:',
	'info_nb_groupe_mots' => '@nb@ keyword groups',
	'info_oui_suppression_mot_cle' => 'I want to delete this keyword permanently.',
	'info_question_mots_cles' => 'Do you wish to use keywords on your site?',
	'info_qui_attribue_mot_cle' => 'Keywords in this group can be assigned by:',
	'info_remplacer_mot' => 'Replace "@titre@"',
	'info_retirer_mot' => 'Remove this keyword',
	'info_retirer_mots' => 'Remove all keywords',
	'info_rubriques_liees_mot' => 'Sections with this keyword',
	'info_selection_un_seul_mot_cle' => 'You can select only <b>one keyword</b> at a time in this group.',
	'info_supprimer_mot' => 'delete this keyword',
	'info_titre_mot_cle' => 'Keyword name or title',
	'info_un_mot' => 'One keyword at a time',
	'item_ajout_mots_cles' => 'Allow the use of keywords in forums',
	'item_non_ajout_mots_cles' => 'Do not allow use of keywords in forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Do not use the advanced keyword group configuration',
	'item_non_utiliser_mots_cles' => 'Do not use keywords',
	'item_utiliser_config_groupe_mots_cles' => 'Use advanced configuration for keyword groups',
	'item_utiliser_mots_cles' => 'Use keywords',

	// L
	'lien_ajouter_mot' => 'Add this keyword',
	'logo_groupe' => 'LOGO FOR THIS GROUP',
	'logo_mot_cle' => 'KEYWORD LOGO',

	// T
	'texte_config_groupe_mots_cles' => 'Do you want to activate advanced keyword configuration, e.g. to indicate that one unique word from the group may be used, that a group is important etc.?',
	'texte_mots_cles' => 'Keywords allow you to create topical links between your articles
  irrespective of their section. This can be used to
  improve site navigability, or even as a tool
  for customising site appearance in a template.',
	'texte_mots_cles_dans_forum' => 'Do you want to let visitors select keywords in the public forums? (Warning: this option is rather difficult to use properly)',
	'texte_nouveau_mot' => 'New keyword',
	'titre_config_groupe_mots_cles' => 'Configuration of the keyword groups',
	'titre_gauche_mots_edit' => 'KEYWORD NUMBER:',
	'titre_groupe_mots' => 'Keyword group',
	'titre_groupe_mots_numero' => 'KEYWORD GROUP NUMBER:',
	'titre_groupes_mots' => 'Keyword groups',
	'titre_mots_cles_dans_forum' => 'Keywords in the public site forums',
	'titre_mots_tous' => 'Keywords',
	'titre_nouveau_groupe' => 'New group',
	'titre_objets_lies_mot' => 'Linked to that keyword:',
	'titre_page_mots_tous' => 'Keywords',
];
